<?php

class GalleryFloorplansWidget extends WP_Widget {
    /** constructor */
    function GalleryFloorplansWidget() {
        parent::WP_Widget(false, $name = __('Floorplan Gallery','floorplans'), array('description' => __('List of all images attached to the current floorplan', 'floorplans')));
    }

    /** @see WP_Widget::widget */
    function widget($args, $instance) {

        global  $floorplans, $post;
        extract( $args );
        $title = apply_filters('widget_title', $instance['title']);
        $image_type = esc_attr($instance['image_type']);
        $big_image_type = esc_attr($instance['big_image_type']);
        $gallery_count = esc_attr($instance['gallery_count']);

        if(empty($big_image_type))
            $big_image_type = 'large';

        if(empty($image_type))
            $image_type = 'thumbnail';
			
			

        $thumbnail_dimensions = FP_Utils::image_sizes($image_type);

        echo $before_widget;
        echo "<div id='floorplans_gallery_widget'>";


        if ( $title )
            echo $before_title . $title . $after_title;

        if($post->gallery) {
            $real_count = 0;
            foreach($post->gallery as $image) {

 
                ?>
                <div class="sidebar_gallery_item">
                <a href="<?php echo $image[$big_image_type]; ?>"  class="fancybox_image" rel="floorplan_gallery">
                    <img src="<?php echo $image[$image_type]; ?>" alt="<?php echo $image[post_title]; ?>" rel="floorplans-gallery" class="size-thumbnail "  width="<?php echo $thumbnail_dimensions[width]; ?>" height="<?php echo $thumbnail_dimensions[height]; ?>" />
                </a>
                </div>
                <?php
                $real_count++;


                if(!empty($gallery_count) && $gallery_count == $real_count)
                    break;

            }
        }

        echo "</div>";
        echo $after_widget;

    }

    /** @see WP_Widget::update */
    function update($new_instance, $old_instance) {
        return $new_instance;
    }

    /** @see WP_Widget::form */
    function form($instance) {

        global $floorplans;
        $title = esc_attr($instance['title']);
        $image_type = $instance['image_type'];
        $big_image_type = $instance['big_image_type'];
        $gallery_count = $instance['gallery_count'];

          ?>
             <p>
                <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?>
                <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
                </label>
            </p>

            <p>
                <label for="<?php echo $this->get_field_id('image_type'); ?>"><?php _e('Thumbnail Size:'); ?>
                <?php FP_Utils::image_sizes_dropdown("name=" . $this->get_field_name('image_type') . "&selected=" . $image_type); ?>
            </label>

            </p>
            <p>
                <label for="<?php echo $this->get_field_id('big_image_type'); ?>"><?php _e('Popup Image Size:'); ?>
                <?php FP_Utils::image_sizes_dropdown("name=" . $this->get_field_name('big_image_type') . "&selected=" . $big_image_type); ?>
            </label>

            </p>
            <p>
            <label for="<?php echo $this->get_field_id('gallery_count') ?>">
               <?php $number_of_images = '<input size="3" type="text" id="'. $this->get_field_id('gallery_count') .'" name="'. $this->get_field_name('gallery_count').'" value="'. $gallery_count.'" />'; ?>
               <?php echo sprintf(__('Show %s Images','floorplans'), $number_of_images); ?>
            </label>

            </p>


         <?php

    }

}



class FloorplanFeaturesWidget extends WP_Widget {
    /** constructor */
    function FloorplanFeaturesWidget() {
        parent::WP_Widget(false, $name = __('Floorplan Features','floorplans'), array('description' => __('List of all features attached to the current floorplan', 'floorplans')));
    }

    /** @see WP_Widget::widget */
    function widget($args, $instance) {
		global  $floorplans, $post;
		extract($args);
		
		if ($post->post_type != 'floorplan') {
			// If this widget is used on a non-floorplan page, it should get the features for all the floorplans	
		}
		
        echo $before_widget;
		
		if ( !empty($instance['title']) )
            echo $before_title . $instance['title'] . $after_title;
		?>
		<ul>
		<?php get_features('type=floorplan_feature&format=list&links=false'); ?>
		</ul>
		<?php
        echo $after_widget;

    }

    /** @see WP_Widget::update */
    function update($new_instance, $old_instance) {
        return $new_instance;
    }

    /** @see WP_Widget::form */
    function form($instance) {

        global $floorplans;
		$title = esc_attr($instance['title']);
		$left_margin = esc_attr($instance['left_margin']);
          ?>
             <p>
                <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?>
                <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
                </label>
            </p>
			<!--<p>
                <label for="<?php echo $this->get_field_id('left_margin'); ?>"><?php _e('Left Margin'); ?>
                <input class="widefat" id="<?php echo $this->get_field_id('left_margin'); ?>" name="<?php echo $this->get_field_name('left_margin'); ?>" type="text" value="<?php echo $left_margin; ?>" />
                </label>
                This lets you move the widget to the right. A good value to start with here is 25px
            </p>-->
            

         <?php

    }

}



class FloorplanStatsWidget extends WP_Widget {
    /** constructor */
    function FloorplanStatsWidget() {
		$control_ops = array( 'id_base' => 'floorplan-stats' );
		$widget_ops = array('classname' => 'floorplan-stats', 'description' => __('Shows all stats (price, style, bedrooms, etc) of the current floorplan', 'floorplans'));
        parent::WP_Widget('floorplan-stats', __('Floorplan Statistics','floorplans'), $widget_ops, $control_ops);
    }

    /** @see WP_Widget::widget */
    function widget($args, $instance) {
		extract($args);
        global  $floorplans, $post;

		if ($post->post_type != 'floorplan') {
			// If this widget is used on a non-floorplan page, it should get the features for all the floorplans	
		}
		
        echo $before_widget;
		
		if ( !empty($instance['title']) )
            echo $before_title . $instance['title'] . $after_title;
			?>
        <div id="floorplan_stats" class="overview_stats">
		<?php draw_stats(""); ?>
        </div>
        <?php
        echo $after_widget;

    }

    /** @see WP_Widget::update */
    function update($new_instance, $old_instance) {
        return $new_instance;
    }

    /** @see WP_Widget::form */
    function form($instance) {

        global $floorplans;
		$title = esc_attr($instance['title']);
		//$left_margin = esc_attr($instance['left_margin']);
          ?>
             <p>
                <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?>
                <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
                </label>
            </p>
            
           <!-- <p>
                <label for="<?php echo $this->get_field_id('left_margin'); ?>"><?php _e('Left Margin'); ?>
                <input class="widefat" id="<?php echo $this->get_field_id('left_margin'); ?>" name="<?php echo $this->get_field_name('left_margin'); ?>" type="text" value="<?php echo $left_margin; ?>" />
                </label>
                This lets you move the widget to the right. A good value to start with here is 25px
            </p>-->

            

         <?php
    }

}


class FloorplanVideoWidget extends WP_Widget {
    /** constructor */
    function FloorplanVideoWidget() {
		$control_ops = array( 'id_base' => 'floorplan-video' );
		$widget_ops = array('classname' => 'floorplan-video', 'description' => __('Shows the video of the current floorplan.', 'floorplans'));
        parent::WP_Widget('floorplan-video', __('Floorplan Video','floorplans'), $widget_ops, $control_ops);
    }

    /** @see WP_Widget::widget */
    function widget($args, $instance) {
		extract($args);
        global  $floorplans, $post;

		if ($post->post_type != 'floorplan') {
			// If this widget is used on a non-floorplan page, it should get the features for all the floorplans	
		}
		
        echo $before_widget;
		
		if ( !empty($instance['title']) )
            echo $before_title . $instance['title'] . $after_title;
			?>
        <div id="floorplan_video">
		<?php echo $post->video_code; ?>
        </div>
        <?php
        echo $after_widget;

    }

    /** @see WP_Widget::update */
    function update($new_instance, $old_instance) {
        return $new_instance;
    }

    /** @see WP_Widget::form */
    function form($instance) {

        global $floorplans;
		$title = esc_attr($instance['title']);
		//$left_margin = esc_attr($instance['left_margin']);
          ?>
             <p>
                <label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?>
                <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" />
                </label>
            </p>
            
           <!-- <p>
                <label for="<?php echo $this->get_field_id('left_margin'); ?>"><?php _e('Left Margin'); ?>
                <input class="widefat" id="<?php echo $this->get_field_id('left_margin'); ?>" name="<?php echo $this->get_field_name('left_margin'); ?>" type="text" value="<?php echo $left_margin; ?>" />
                </label>
                This lets you move the widget to the right. A good value to start with here is 25px
            </p>-->

            

         <?php
    }

}
?>