<?php
if(!function_exists('prepare_floorplan_for_display')):
	/**
	 * Runs all filters through floorplan variables
	 *
	 * @since 1.4
	 *
 	 */
	 function prepare_floorplan_for_display($floorplan) {
 
		if(empty($floorplan))
			return;
		if (empty($floorplan[floorplan_type])) $floorplan[floorplan_type] = 0;
		if (empty($floorplan[floorplan_collection])) $floorplan[floorplan_collection] = 0;
		foreach($floorplan as $meta_key => $attribute)
 			$floorplan[$meta_key] = apply_filters("fp_stat_filter_$meta_key",$attribute);

		
		// Go through children floorplans
		if(is_array($floorplan[children]))
			foreach($floorplan[children] as $child => $child_data)  
				$floorplan[children][$child] = prepare_floorplan_for_display($child_data);
		
		
	
		return $floorplan;	
	}
	
endif;
	
if(!function_exists('floorplan_slideshow')):
	/**
	 * Returns floorplan slideshow images, or single image if plugin not installed
	 *
	 * @since 1.0
	 *
 	 */
	 function floorplan_slideshow($args = "") {
		global $floorplans, $post;
		
		
		
		
		$defaults = array('force_single' => false, 'return' => false);
		$args = wp_parse_args( $args, $defaults );
		
		if($floorplans[configuration][floorplan_overview][display_slideshow] == 'false')
			return;
			
			
		ob_start();
			
			// Display slideshow if premium plugin exists and the floorplan isn't set to hide slideshow
			if($floorplans[plugins][slideshow][status] == 'enabled' && !$post->disable_slideshow) {
				fp_slideshow::display_floorplan_slideshow(fp_slideshow::get_floorplan_slideshow_images($post->ID));
			} else {
				// Get slideshow image type for featured image
				
				if(!empty($post->slideshow)) {
					echo "<a href='{$post->featured_image_url}' class='fancybox_image'>";
					echo "<img src='{$post->slideshow}' alt='{$post->featured_image_title}' />";
					echo "</a>";
				}
			}
				
			
			
			
		$content = ob_get_contents();
		ob_end_clean();
		
		if(empty($content))
			return false;
		
		if($return)
			return $content;
			
		echo $content;
		
		
	}
endif; // floorplan_slideshow


/*
	Extends get_post by dumping all metadata into array
*/
if(!function_exists('get_floorplan')):
	function get_floorplan($id, $args = "") {
		if($id && is_numeric($id))
			return FP_Utils::get_floorplan($id, $args);
	}
endif;

if(!function_exists('get_features')):
	function get_features($args = '') {
		global $post;

		$defaults = array('type' => 'floorplan_feature', 'format' => 'comma', 'links' => true);
		$args = wp_parse_args( $args, $defaults );



		$features = get_the_terms($post->ID, $args[type]);

		$features_html = array();

		if($features) {
		foreach ($features as $feature)

			if($links)
				array_push($features_html, '<a href="' . get_term_link($feature->slug, $args[type]) . '">' . $feature->name . '</a>');
			else
				array_push($features_html, $feature->name);

			if($args[format] == 'comma')
				echo implode($features_html, ", ");

			if($args[format] == 'array')
				return $features_html;

			if($args[format] == 'count')
				return (count($features) > 0 ? count($features) : false);

			if($args[format] == 'list')
				echo "<li>" . implode($features_html, "</li><li>") . "</li>";

		}


	}
endif;

if(!function_exists('draw_stats')):
	function draw_stats($args = false){
		global $floorplans, $post;
		$defaults = array( );
		extract( wp_parse_args( $args, $defaults ), EXTR_SKIP );

 
		$stats = FP_Utils::get_stat_values_and_labels($post, $args);

		//print_r($stats);
		if(!$stats)
			return;
        $alt = 'alt';
        foreach($stats as $label => $value){
            $labels_to_keys = array_flip($floorplans['floorplan_stats']);
            if(empty($value))
               return;

            $tag = $labels_to_keys[$label];

            if ($alt == '' )
                $alt = "alt"; 
            else 
                $alt = '';
			?>
			<dt class="fp_stat_dt_<?php echo $tag; ?>"><?php echo $label; ?></dt>
			<dd class="fp_stat_dd_<?php echo $tag; ?> <?php echo $alt ?>"><?php echo $value ?>&nbsp;</dd>
		<?php } ?>
 
		<?php
	}
endif;


if(!function_exists('draw_featured_floorplans')):
	function draw_featured_floorplans() {
	?>


	    <?php
		$featured_array = fp_F::get_floorplans("featured=true&floorplan_type=all");

	    if(is_array($featured_array)):
			foreach($featured_array as $featured):

				unset($this_floorplan);
				$this_floorplan = fp_F::get_floorplan($featured->ID);

				?>
				<div class="apartment_entry clearfix" style="clear:both;margin-bottom:15px;">

					<a href="<?php echo $this_floorplan[permalink]; ?>">
						<img src="<?php echo $this_floorplan[sidebar_gallery_thumb];?>" alt="<?php echo sprintf(__('%s at %s for %s','floorplans'), $this_floorplan[post_title], $this_floorplan[location], $this_floorplan[price]); ?>" />
					</a>

					<ul class="sidebar_floorplans">
						<li><span><?php _e('Price:','floorplans'); ?></span> $ <?php echo  $this_floorplan[price]; ?></li>
						<li><span><?php _e('Bed(s):','floorplans'); ?></span> <?php echo  $this_floorplan[bedrooms]; ?></li>
						<li><span><?php _e('Bath(s):','floorplans'); ?></span> <?php echo  $this_floorplan[bathrooms]; ?></li>
						<li><span><?php _e('Square Ft:','floorplans'); ?></span> <?php echo  $this_floorplan[area]; ?></li>
					</ul>
			   </div>
			  <?php
			endforeach;
		endif;


	}
endif;

	/**
	 * Draws search form
	 *
	 *
	 * @return array|$floorplans
	 * @since 0.57
	 *
 	 */
if(!function_exists('draw_floorplan_search_form')):
	function draw_floorplan_search_form($search_attributes = false, $searchable_floorplan_types = false, $per_page = false) {
        global $floorplans;
  
        if(!$search_attributes)
            return;
            
        $search_values = array();
        if (!empty($search_attributes) && !empty($searchable_floorplan_types))
            $search_values = FP_Utils::get_search_values($search_attributes, $searchable_floorplan_types);
        ?>
 
        <form action="<?php echo  FP_UD::base_url($floorplans['configuration']['base_slug']); ?>" method="post">
            
		<?php
		if(is_array($searchable_floorplan_types)) foreach($searchable_floorplan_types as $this_floorplan) {
            echo '<input type="hidden" name="fp_search[floorplan_type][]" value="'. $this_floorplan .'" />';
		} ?>
				
            <ul class="fp_search_elements">
                <?php if(is_array($search_attributes)) foreach($search_attributes as $attrib) {
                    // Don't display search attributes that have no values
                    if(!isset($search_values[$attrib]))
                        continue;
                    ?>
                    <li class="seach_attribute_<?php echo $attrib; ?>">
                        <label class="fp_search_label fp_search_label_<?php echo $attrib; ?>" for="fp_search_input_field_<?php echo $attrib; ?>"><?php echo (empty($floorplans['floorplan_stats'][$attrib]) ? ucwords($attrib) : $floorplans['floorplan_stats'][$attrib]) ?>:</label>
                        
                        <?php if(!empty($floorplans['searchable_attr_fields'][$attrib])) : ?>
                            
                            <?php switch($floorplans['searchable_attr_fields'][$attrib]) {
                            	case 'input' :
                            	    ?>
                            	    <input name="fp_search[<?php echo $attrib; ?>]" value="<?php echo $_REQUEST['fp_search'][$attrib]; ?>" />
                            	    <?php
                            	    break;
                                case 'range_input':
                                    ?>
                                    <input  id="fp_search_input_field_<?php echo $attrib; ?>"  class="fp_search_input_field_min fp_search_input_field_<?php echo $attrib; ?>" type="text" name="fp_search[<?php  echo $attrib; ?>][min]" value="<?php echo $_REQUEST['fp_search'][$attrib]['min']; ?>" /> -
                                	<input class="fp_search_input_field_max fp_search_input_field_<?php echo $attrib; ?>"  type="text" name="fp_search[<?php echo $attrib; ?>][max]" value="<?php echo $_REQUEST['fp_search'][$attrib]['max']; ?>" />
                                    <?php
                                    break;
                                case 'range_dropdown':
                                    ?>
                                    <select id="fp_search_input_field_<?php echo $attrib; ?>" class="fp_search_select_field fp_search_select_field_<?php echo $attrib; ?>" name="fp_search[<?php echo $attrib; ?>][min]" >
                                    <option value="0"><?php _e('Any','floorplans') ?></option>
                                    <?php foreach($search_values[$attrib] as $value) { ?>
                                        <option value='<?php echo (int)$value; ?>' <?php if($_REQUEST['fp_search'][$attrib]['min'] == $value) echo " selected='true' "; ?>>
                                            <?php echo apply_filters("fp_stat_filter_range_plus", $value); ?>
                                        </option>
                                    <?php } ?>
                                	</select>
                                    <?php
                                    break;
                                case 'dropdown':
                                    ?>
                                    <select id="fp_search_input_field_<?php echo $attrib; ?>" class="fp_search_select_field fp_search_select_field_<?php echo $attrib; ?>" name="fp_search[<?php echo $attrib; ?>]" >
                                    <option value="-1"><?php _e('Any','floorplans') ?></option>
                                    <?php foreach($search_values[$attrib] as $value) { ?>
                                        <option value='<?php echo $value; ?>' <?php if($_REQUEST['fp_search'][$attrib] == $value) echo " selected='true' "; ?>>
                                            <?php echo apply_filters("fp_stat_filter_$attrib", $value); ?>
                                        </option>
                                    <?php } ?>
                                	</select>
                                    <?php
                                    break;
                                case 'checkbox':
                                    ?>
                                    <input type="checkbox" name="fp_search[<?php echo $attrib; ?>][checked]" <?php if($_REQUEST['fp_search'][$attrib]['checked'] == 'on') echo " checked='checked' "; ?> /> 
                                    <?php
                                    break;
                            } ?>
                        
                        <?php else: ?>
                        
                            <?php
                            // Determine if attribute is a numeric range
                            if(FP_Utils::is_numeric_range($search_values[$attrib])) {
                            ?>
                                <input  id="fp_search_input_field_<?php echo $attrib; ?>"  class="fp_search_input_field_min fp_search_input_field_<?php echo $attrib; ?>" type="text" name="fp_search[<?php  echo $attrib; ?>][min]" value="<?php echo $_REQUEST['fp_search'][$attrib]['min']; ?>" /> -
                                <input class="fp_search_input_field_max fp_search_input_field_<?php echo $attrib; ?>"  type="text" name="fp_search[<?php echo $attrib; ?>][max]" value="<?php echo $_REQUEST['fp_search'][$attrib]['max']; ?>" />
                            <?php
                            }  else { /* Not a numeric range */ ?>
                                <select id="fp_search_input_field_<?php echo $attrib; ?>" class="fp_search_select_field fp_search_select_field_<?php echo $attrib; ?>" name="fp_search[<?php echo $attrib; ?>]" >
                                    <option value="-1"><?php _e('Any','floorplans') ?></option>
                                    <?php foreach($search_values[$attrib] as $value) { ?>
                                        <option value='<?php echo $value; ?>' <?php if($_REQUEST['fp_search'][$attrib] == $value) echo " selected='true' "; ?>>
                                            <?php echo apply_filters("fp_stat_filter_$attrib", $value); ?>
                                        </option>
                                    <?php } ?>
                                </select>
                            <?php } ?>
                        
                        <?php endif; ?>
                        <div class="clear"></div>
                    </li>
                <?php } ?>
                <li class="submit"><input type="submit" class="fp_search_button submit" value="<?php _e('Search','floorplans') ?>" /></li>
            </ul>
            <?php if($per_page) echo '<input type="hidden" name="fp_search[pagi]" value="0--'. $per_page .'" />'; ?>
        </form>
    <?php }
		
endif;
?>